@@ -271,8 +271,8 @@ def All_TMEs_in_Image_(clusters,dataset,subject_info):
                 last_patch = 0
                 aux_2 = []
                 for im_i in Patch_IMS:
-                    aux_2.append(np.reshape(aux[last_patch:last_patch+im_i.max()+1],(im_i.shape[1],im_i.shape[0])))                    
-                    last_patch = last_patch+im_i.max()+1
+                    aux_2.append(np.transpose(np.reshape(aux[last_patch:last_patch+im_i.max()-im_i.min()+1],(im_i.shape[1],im_i.shape[0]))))                    
+                    last_patch = last_patch+im_i.max()-im_i.min()+1
                 aux = np.concatenate(aux_2,1)                
 
                 # Interpolate aux image to match size with the original one.
@@ -280,15 +280,15 @@ def All_TMEs_in_Image_(clusters,dataset,subject_info):
 
             # Save image of labels as a multitiff.
             if cell_type_idx==0:
-                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Phenotypesss.tif'.format(subject_info[0]),np.moveaxis(Labels,2,0),photometric='minisblack')                
+                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Phenotypes.tif'.format(subject_info[0]),np.moveaxis(Labels,2,0),imagej=True,metadata={'axes': Labels.shape[2], 'unit': 'um','axes': 'CYX'})                
             elif cell_type_idx==1:
-                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Neighborhoods.tif'.format(subject_info[0]), np.moveaxis(Labels,2,0), photometric='minisblack')        
+                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Neighborhoods.tif'.format(subject_info[0]), np.moveaxis(Labels,2,0),imagej=True,metadata={'axes': Labels.shape[2], 'unit': 'um','axes': 'CYX'})        
             else:
-                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Areas.tif'.format(subject_info[0]), np.moveaxis(Labels,2,0), photometric='minisblack')       
+                imwrite(dataset.bioInsights_dir_TME_in_image+'{}_Areas.tif'.format(subject_info[0]), np.moveaxis(Labels,2,0),imagej=True,metadata={'axes': Labels.shape[2], 'unit': 'um','axes': 'CYX'})       
 
             # Save original image
-            if dataset.args['Bio_save_Orig_im']:                
-                imwrite(dataset.bioInsights_dir_TME_in_image+'{}.tif'.format(subject_info[0]), np.moveaxis(np.concatenate(imList,1),2,0), photometric='minisblack')  
+            if dataset.args['Bio_save_Orig_im'] and cell_type_idx==0:                
+                imwrite(dataset.bioInsights_dir_TME_in_image+'{}.tif'.format(subject_info[0]), np.moveaxis(np.concatenate(imList,1),2,0),imagej=True,metadata={'axes': Labels.shape[2], 'unit': 'um','axes': 'CYX'})  
 
 
         del im, imList, PCL_reprsntions, Patch_im
