@@ -347,7 +347,7 @@ def parameters(path, debug):
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
         args['PCL_N_Workers']=8 # Number of data loading workers 
-        args['PCL_Epochs']=250 # Number of total epoch to run
+        args['PCL_Epochs']=500 # Number of total epoch to run
         args['PCL_N_Crops_per_Image']=30 # Number of crops chosen per image
         args['PCL_Patch_Size']=30 # Size of patches in pixels
         args['PCL_Stride']=0 # Size of stride between consecutive patches
@@ -639,7 +639,7 @@ def parameters(path, debug):
         args['num_samples_architecture_search'] = 1500  
 
         # Optimization Parameters
-        args['NaroNet_n_workers'] = 1
+        args['NaroNet_n_workers'] = 10
         args['epochs'] = 1000
         args['lr_decay_factor'] = 0.1
         args['lr_decay_step_size'] = 10000
@@ -704,7 +704,7 @@ def parameters(path, debug):
         args['PCL_Color_perturbation_Augmentation'] = False # Color augmentation for H&E tissue staining.
 
         # Label you want to infer with respect the images.
-        args['experiment_Label'] = ['Patient_Status'] 
+        args['experiment_Label'] = ['Unsupervised'] 
 
         # Architecture Search parameters
         args['num_samples_architecture_search'] = 1500  
@@ -726,8 +726,8 @@ def parameters(path, debug):
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
 
         # Neural Network
-        args['N_Phenotypes'] = 8
-        args['N_Neighborhoods'] = 12
+        args['N_Phenotypes'] = 6
+        args['N_Neighborhoods'] = 10
         args['N_Areas'] = 4
         args['n_hops_neighborhoods'] = 2
         args['Phenotype_Learning'] = True  
@@ -747,11 +747,11 @@ def parameters(path, debug):
         args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
         
         # Bioinsights parameters
-        args['Bio_save_Orig_im'] = True
+        args['Bio_save_Orig_im'] = True # Whether to save raw data again. Helpful when patients are composed by more than one image since it creates a mosaic.
         args['TSNE_Perc_Pat'] = 0 # Percentage of patients used to calculate TSNE. 1 is 100% of patients
         args['Pheno_Perc_Pat'] = 1 # Percentage of patients used to calculate TSNE. 1 is 100% of patients
-        args['Pheno_Excluded_from_analysis'] = [] # Percentage of patients used to calculate TSNE. 1 is 100% of patients
-        args['Neigh_Excluded_from_analysis'] = [] # Percentage of patients used to calculate TSNE. 1 is 100% of patients
+        args['Pheno_Excluded_from_analysis'] = [] # Phenotype excluded from the analysis e.g., [1], [3,7] for eliminating phenotype 1 and phenotypes 3 and 7, respectively
+        args['Neigh_Excluded_from_analysis'] = [] # Neighborhoods excluded from the analysis e.g., [1], [3,7] for eliminating neighborhood 1 and phenotypes 3 and 7, respectively
 
 
     else:
